module TT_GroupsToComponents

  unless file_loaded?( __FILE__ )
    # Menus
    m = UI.menu( 'Plugins' )
    m.add_item( 'Convert Groups to Components' ) {
      self.convert_group_copies_to_components
    }
  end 

  def self.convert_group_copies_to_components
    model = Sketchup.active_model
    model.start_operation( 'Convert Groups to Components', true )
    groups = model.definitions.select { |d| d.group? }
    for group_definition in groups
      self.group_definition_to_component( group_definition )
    end
    model.commit_operation
  end

  def self.group_definition_to_component( group_definition )
    group = group_definition.instances[0]
    # Cache some properties to transfer
    group_name = group.name
    group_lock = group.locked?
    # Find all the copies and make a prototype
    groups = group_definition.instances
    proto = group.to_component
    # Transfer some properties that where not converted
    proto.name = group_name
    proto.locked = group_lock
    
    # Iterate through the rest of the copies
    protodef = proto.definition
    for group in groups
      next if group.deleted?
      # Add a new component
      new_comp          = group.parent.entities.add_instance(protodef, group.transformation)
      new_comp.name     = group.name
      new_comp.material = group.material
      new_comp.layer    = group.layer
      new_comp.hidden   = group.hidden?
      new_comp.casts_shadows    = group.casts_shadows?
      new_comp.receives_shadows = group.receives_shadows?
      new_comp.locked   = group.locked?
      # (!) Glued to, attributes?
      # Delete the old group
      group.locked = false
      group.parent.entities.erase_entities(group)
    end
  end

end

file_loaded( __FILE__ )
